@@ -14,7 +14,7 @@ int main(int argc, char *argv[])
         public:
             enum                // enums OK
             {
-                value = 5
+                VALUE = 5
             };
             Local(int argc)     // constructors and member functions OK
             :                   // in-class implementation required
@@ -30,10 +30,6 @@ int main(int argc, char *argv[])
                 cout << "hello world\n";
             }
     };
-
     Local::hello();             // call Local static member
-
     Local loc(argc);            // define object of a local class.
-
-    return 0;
 }
