@@ -10,7 +10,7 @@
 
     Test::Test(string const &name)
     {
-        cout << "Test object " << name << " created" << endl;
+        cout << "Test object " << name << " created" << '\n';
     }
 
     Test globaltest("global");
@@ -25,7 +25,6 @@
         Test first("main first");
         func();
         Test second("main second");
-        return 0;
     }
 /*
     Generated output:
