@@ -3,8 +3,8 @@
     template <typename _Tp>
     struct bitAnd: public std::binary_function<_Tp, _Tp, _Tp>
     {
-        _Tp operator()(_Tp const &__x, _Tp const &__y) const
+        _Tp &&operator()(_Tp const &__x, _Tp const &__y) const
         {
-            return __x & __y;
+            return std::move(__x & __y);
         }
     };
