@@ -18,15 +18,15 @@
         public:
             bool operator!=(RandomPtrIterator const &other) const;
             int operator-(RandomPtrIterator const &rhs) const;
-            RandomPtrIterator const operator+(int step) const;
+            RandomPtrIterator operator+(int step) const;
             Type &operator*() const;
             bool operator<(RandomPtrIterator const &other) const;
             RandomPtrIterator &operator--();
-            RandomPtrIterator const operator--(int);
+            RandomPtrIterator operator--(int);
             RandomPtrIterator &operator++();
-            RandomPtrIterator const operator++(int);
+            RandomPtrIterator operator++(int);
             bool operator==(RandomPtrIterator const &other) const;
-            RandomPtrIterator const operator-(int step) const;
+            RandomPtrIterator operator-(int step) const;
             RandomPtrIterator &operator-=(int step);
             RandomPtrIterator &operator+=(int step);
             Type *operator->() const;
@@ -53,7 +53,7 @@
         return d_current - rhs.d_current;
     }
     template <typename Class, typename BaseIterator, typename Type>
-    RandomPtrIterator<Class, BaseIterator, Type> const
+    RandomPtrIterator<Class, BaseIterator, Type>
     RandomPtrIterator<Class, BaseIterator, Type>::operator+(int step) const
     {
         return RandomPtrIterator(d_current + step);
@@ -81,7 +81,7 @@
         return *this;
     }
     template <typename Class, typename BaseIterator, typename Type>
-    RandomPtrIterator <Class, BaseIterator, Type> const
+    RandomPtrIterator <Class, BaseIterator, Type>
     RandomPtrIterator<Class, BaseIterator, Type>::operator--(int)
     {
         return RandomPtrIterator(d_current--);
@@ -95,7 +95,7 @@
         return *this;
     }
     template <typename Class, typename BaseIterator, typename Type>
-    RandomPtrIterator<Class, BaseIterator, Type> const
+    RandomPtrIterator<Class, BaseIterator, Type>
     RandomPtrIterator<Class, BaseIterator, Type>::operator++(int)
     {
         return RandomPtrIterator(d_current++);
@@ -108,7 +108,7 @@
         return d_current == other.d_current;
     }
     template <typename Class, typename BaseIterator, typename Type>
-    RandomPtrIterator<Class, BaseIterator, Type> const
+    RandomPtrIterator<Class, BaseIterator, Type>
     RandomPtrIterator<Class, BaseIterator, Type>::operator-(int step) const
     {
         return RandomPtrIterator(d_current - step);
