@@ -1,16 +1,16 @@
     #include "monitor.h"
 
+//MAIN
     int main()
     try
     {
-        Monitor monitor;
-
-        monitor.run();
+        Monitor().run();
     }
     catch (int exitValue)
     {
         return exitValue;
     }
+//=
 
     /*
         Example of a session:
