@@ -13,6 +13,7 @@
         size_t const size = sizeof(words) / sizeof(string);
         string result[size];
 
+        // Note: the comparisons are: "mike" > word[i]
         replace_copy_if(words, words + size, result,
                         bind1st(greater<string>(), string("mike")),
                         string("ALPHA"));
@@ -20,6 +21,7 @@
         cout << '\n';
     }
     /*
-        Displays:
+        Displays (all strings in words[] which are exceeded by 'mike' are
+                  replaced by ALPHA):
             ALPHA ALPHA ALPHA mike ALPHA november ALPHA oscar ALPHA ALPHA papa
     */
